@@ -25,7 +25,7 @@ int getopt(int argc, char *argv[], char *optstring){
 
 	if (optind >= argc) return -1;
 	optarg = argv[optind];
-	if (optarg[0] != '-') return 0;
+	if (optarg[0] != '-') return -1;
 	
 	c = optarg[1];
 	cc = strchr(optstring, c);
