@@ -13,6 +13,7 @@
 #include <stdarg.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 
 #include <zsdl.h>
 #ifdef Z_HAVE_SDL
@@ -64,24 +65,25 @@ struct zzsdl *zsdl = NULL;
 #endif
 
 
-struct zzsdl *zsdl_init(SDL_Surface *screen, int font_h){
+struct zzsdl *zsdl_init(SDL_Surface *screen, int font_h, int inverse){
 
     if (zsdl) zsdl_free();
     zsdl = g_new0(struct zzsdl, 1);
+	zsdl->inverse = inverse;
 
     switch(screen->format->BytesPerPixel){
         case 1:
-            zsdl->putpixel = z_putpixel8;
+            zsdl->putpixel = inverse ? z_putpixel8inv : z_putpixel8;
             break;
         case 2:
-            zsdl->putpixel = z_putpixel16;
+            zsdl->putpixel = inverse ? z_putpixel16inv : z_putpixel16;
             break;
         case 3:
-            zsdl->putpixel = z_putpixel24;
+            zsdl->putpixel = inverse ? z_putpixel24inv : z_putpixel24;
 			if (screen->format->Bmask == 0xff) zsdl->antialiasing_supported = 1;
             break;
         case 4:
-            zsdl->putpixel = z_putpixel32;
+            zsdl->putpixel = inverse ? z_putpixel32inv : z_putpixel32;
 			if (screen->format->Bmask == 0xff) zsdl->antialiasing_supported = 1;
             break;
     }
@@ -258,6 +260,41 @@ void z_putpixel32(SDL_Surface *surface, int x, int y, int color){
     *p = color;
 }
 
+void z_putpixel8inv(SDL_Surface *surface, int x, int y, int color){
+    Uint8 *p;
+
+    if (z_clip_pixel(&surface->clip_rect, x, y)) return;
+    p = (Uint8 *) surface->pixels + y*surface->pitch + x;
+    *p = ~color;
+}
+
+void z_putpixel16inv(SDL_Surface *surface, int x, int y, int color){
+    Uint16 *p;
+
+    if (z_clip_pixel(&surface->clip_rect, x, y)) return;
+    p = (Uint16 *) surface->pixels + y*surface->pitch/2 + x;
+    *p = ~color;
+}
+
+void z_putpixel24inv(SDL_Surface *surface, int x, int y, int color){
+    Uint16 *p16;
+    Uint8  *p8;
+
+    if (z_clip_pixel(&surface->clip_rect, x, y)) return;
+    p16 = (Uint16 *) surface->pixels + y*surface->pitch/3 + x;
+    p8  = (Uint8 *)  (p16+1); 
+    *p16 = ~color;     /* TODO Big endian? */
+    *p8  = ~(color>>16); 
+}
+
+void z_putpixel32inv(SDL_Surface *surface, int x, int y, int color){
+    Uint32 *p;
+
+    if (z_clip_pixel(&surface->clip_rect, x, y)) return;
+    p = (Uint32 *) surface->pixels + y*surface->pitch/4 + x;
+    *p = ~color;
+}
+
 /*void z_putpixel32a(SDL_Surface *surface, double x, double y, int color){
     Uint32 *p;
 	double xi, yi;
@@ -1394,3 +1431,7 @@ int z_point_is_in_quadrangle(double xp, double yp, double x1, double y1, double
 
     return 1;
 }
+
+
+
+
